/*
 * CrudContainer
 * Copyright (C) 2011 by Apaq
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package dk.apaq.crud.core;

import dk.apaq.crud.CrudEvent;
import dk.apaq.crud.CrudListener;

/**
 * An abstract implementation of a <code>CrudListener</code> that has empty implementations
 * of all methods in  the interface. A class can extend this class and only implement the methods it need.
 */
public abstract class BaseCrudListener<IDT, BT> implements CrudListener<IDT, BT> {

    /**
     * {@inheritDoc}
     */
    @Override
    public void onBeforeEntityCreate(CrudEvent.WithEntity<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onBeforeEntityDelete(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onBeforeEntityRead(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onBeforeEntityUpdate(CrudEvent.WithIdAndEntity<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onEntityCreate(CrudEvent.WithIdAndEntity<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onEntityDelete(CrudEvent.WithId<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onEntityRead(CrudEvent.WithIdAndEntity<IDT, BT> event) { /* EMPTY */ }

    /**
     * {@inheritDoc}
     */
    @Override
    public void onEntityUpdate(CrudEvent.WithIdAndEntity<IDT, BT> event) { /* EMPTY */ }


}
